
Trademark Usage
``````````````````````````````````````
Why is it important to use the TM, SM, and ® for our registered marks?

Before a trademark is registered with the United States Patent and Trademark Office it is appropriate to use the TM or SM symbol depending whether the product is for goods or services. It is important to use the TM or SM as it is notification to the public that Ansible claims rights to the mark even though it has not yet been registered. 

Once the trademark is registered, it is appropriate to use the symbol in place of the TM or SM. The symbol designation must be used in conjunction with the trademark if Ansible is to fully protect its rights. If we don't protect these marks, we run the risk of losing them in the way of Aspirin or Trampoline or Escalator.

General Rules: 
+++++++++++++++

Trademarks should be used on 1st references on a page or within a section.

Use Red Hat® Ansible Tower® or Ansible®, on first reference when referring to products.
 
Use "Ansible" alone as the company name, as in "Ansible announced quarterly results," which is not marked.

Also add the trademark disclaimer.
* When using Ansible trademarks in the body of written text, you should use the following credit line in a prominent place, usually a footnote.

    For Registered Trademarks:
    - [Name of Trademark] is a registered trademark of Red Hat, Inc. in the United States and other countries.
    
    For Unregistered Trademarks (TMs/SMs):
    - [Name of Trademark] is a trademark of Red Hat, Inc. in the United States and other countries.

    For registered and unregistered trademarks:
    - [Name of Trademark] is a registered trademark and [Name of Trademark] is a trademark of Red Hat, Inc. in the United States and other countries.

Guidelines for the proper use of trademarks:
+++++++++++++++++++++++++++++++++++++++++++++
 
 Always distinguish trademarks from surround text with at least initial capital letters or in all capital letters.

Always use proper trademark form and spelling.

Never use a trademark as a noun. Always use a trademark as an adjective modifying the noun.

    Correct:
    Red Hat® Ansible Tower® system performance is incredible.

    Incorrect:
    Ansible's performance is incredible.
    
Never use a trademark as a verb. Trademarks are products or services, never actions.

    Correct:
    "Orchestrate your entire network using Red Hat® Ansible Tower®."
    
    Incorrect:
    "Ansible your entire network."

Never modify a trademark to a plural form. Instead, change the generic word from the singular to the plural.

    Correct:
    "Corporate demand for Red Hat® Ansible Tower® configuration software is surging."

    Incorrect:
    "Corporate demand for Ansible is surging."
    
Never modify a trademark from its possessive form, or make a trademark possessive. Always use it in the form it has been registered.

Never translate a trademark into another language.

Never use trademarks to coin new words or names.

Never use trademarks to create a play on words.

Never alter a trademark in any way including through unapproved fonts or visual identifiers.

Never abbreviate or use any Ansible trademarks as an acronym.

The importance of Ansible trademarks
++++++++++++++++++++++++++++++++++++++++++++++++

The Ansible trademark and the "A" logo in a shaded circle are our most valuable assets. The value of these trademarks encompass the Ansible Brand. Effective trademark use is more than just a name, it defines the level of quality the customer will receive and it ties a product or service to a corporate image. A trademark may serve as the basis for many of our everyday decisions and choices. The Ansible Brand is about how we treat customers and each other. In order to continue to build a stronger more valuable Brand we must use it in a clear and consistent manner.

The mark consists of the letter "A" in a shaded circle. As of 5/11/15, this was a pending trademark (registration in process).

Common Ansible Trademarks
+++++++++++++++++++++++++++++++++++++++
* Ansible®
* Ansible Tower®

Other Common Trademarks and Resource Sites:
++++++++++++++++++++++++++++++++++++++++++++++++
- Linux is a registered trademark of Linus Torvalds.
- UNIX® is a registered trademark of The Open Group.
- Microsoft, Windows, Vista, XP, and NT are registered trademarks or trademarks of Microsoft Corporation in the United States and/or other countries. https://www.microsoft.com/en-us/legal/intellectualproperty/trademarks/en-us.aspx
- Apple, Mac, Mac OS, Macintosh, Pages and TrueType are either registered trademarks or trademarks of Apple Computer, Inc. in the United States and/or other countries. https://www.apple.com/legal/intellectual-property/trademark/appletmlist.html
- Adobe, Acrobat, GoLive, InDesign, Illustrator, PostScript , PhotoShop and the OpenType logo are either registered trademarks or trademarks of Adobe Systems Incorporated in the United States and/or other countries. https://www.adobe.com/legal/permissions/trademarks.html
- Macromedia and Macromedia Flash are trademarks of Macromedia, Inc. https://www.adobe.com/legal/permissions/trademarks.html
- IBM is a registered trademark of International Business Machines Corporation. https://www.ibm.com/legal/us/en/copytrade.shtml
- Celeron, Celeron Inside, Centrino, Centrino logo, Core Inside, Intel Core, Intel Inside, Intel Inside logo, Itanium, Itanium Inside, Pentium, Pentium Inside,VTune, Xeon, and Xeon Inside are trademarks or registered trademarks of Intel Corporation or its subsidiaries in the United States and other countries. https://www.intel.com/content/www/us/en/legal/trademarks.html

